@@ -21,6 +21,7 @@ sabnzbd.notifier - Send notifications to any notification services
 """
 
 
+import sys
 import os.path
 import logging
 import platform
@@ -45,13 +46,17 @@ if sabnzbd.WINDOWS:
         from windows_toasts import InteractableWindowsToaster, Toast, ToastActivatedEventArgs, ToastButton
 
         # Only Windows 10 and above are supported
-        if int_conv(platform.release()) < 10:
+        if int_conv(platform.version().split(".")[0]) < 10:
             raise OSError
 
         # Set a custom AUMID to display the right icon, it is written to the registry by the installer
         shell.SetCurrentProcessExplicitAppUserModelID("SABnzbd")
         _HAVE_WINDOWS_TOASTER = True
-    except:
+    except Exception:
+        # This needs to work on Windows releases
+        if hasattr(sys, "frozen"):
+            raise
+
         # Sending toasts on non-supported platforms results in segfaults
         _HAVE_WINDOWS_TOASTER = False
 
@@ -64,7 +69,7 @@ try:
     # Without DISPLAY, notify2 cannot autolaunch a dbus-daemon
     if not hasattr(notify2, "init") or "DISPLAY" not in os.environ:
         _HAVE_NTFOSD = False
-except:
+except Exception:
     _HAVE_NTFOSD = False
 
 
@@ -90,6 +95,7 @@ NOTIFICATION_TYPES = {
 NOTIFICATION_ACTIONS = {
     "open_folder": TT("Open folder"),  #: Notification action
     "open_complete": TT("Open complete folder"),  #: Notification action
+    "open_update_page": TT("Download"),
 }
 
 
@@ -217,7 +223,7 @@ def send_notify_osd(title, message):
     # when there's no active notification daemon
     try:
         _NTFOSD = _NTFOSD or notify2.init("SABnzbd")
-    except:
+    except Exception:
         _NTFOSD = False
 
     if _NTFOSD:
@@ -225,7 +231,7 @@ def send_notify_osd(title, message):
         try:
             note = notify2.Notification(title, message, icon)
             note.show()
-        except:
+        except Exception:
             # Apparently not implemented on this system
             logging.info(error)
             return error
@@ -248,7 +254,7 @@ def send_notification_center(title: str, msg: str, notification_type: str, actio
                 break
 
         sabnzbd.MACOSTRAY.send_notification(title, subtitle, msg, button_text, button_action)
-    except:
+    except Exception:
         logging.info(T("Failed to send macOS notification"))
         logging.debug("Traceback: ", exc_info=True)
         return T("Failed to send macOS notification")
@@ -280,7 +286,7 @@ def send_prowl(title, msg, notification_type, force=False, test=None):
         try:
             urllib.request.urlopen(url)
             return ""
-        except:
+        except Exception:
             logging.warning(T("Failed to send Prowl message"))
             logging.info("Traceback: ", exc_info=True)
             return T("Failed to send Prowl message")
@@ -365,7 +371,7 @@ def send_apprise(title, msg, notification_type, force=False, test=None):
         ):
             return T("Failed to send one or more Apprise Notifications")
 
-    except:
+    except Exception:
         logging.warning(T("Failed to send Apprise message"))
         logging.info("Traceback: ", exc_info=True)
         return T("Failed to send Apprise message")
@@ -434,7 +440,7 @@ def do_send_pushover(body):
             return T("Failed to send pushover message")
         else:
             return ""
-    except:
+    except Exception:
         logging.warning(T("Failed to send pushover message"))
         logging.info("Traceback: ", exc_info=True)
         return T("Failed to send pushover message")
@@ -468,7 +474,7 @@ def send_pushbullet(title, msg, notification_type, force=False, test=None):
         else:
             logging.info("Successfully sent to Pushbullet")
 
-    except:
+    except Exception:
         logging.warning(T("Failed to send pushbullet message"))
         logging.info("Traceback: ", exc_info=True)
         return T("Failed to send pushbullet message")
@@ -506,7 +512,7 @@ def send_nscript(title, msg, notification_type, force=False, test=None):
                 )
                 output = p.stdout.read()
                 ret = p.wait()
-            except:
+            except Exception:
                 logging.info("Failed to run script %s", script, exc_info=True)
 
             if ret:
@@ -540,7 +546,7 @@ def send_windows(title: str, msg: str, notification_type: str, actions: Optional
             notification_sender.show_toast(toast_notification)
         elif sabnzbd.WINTRAY and not sabnzbd.WINTRAY.terminate:
             sabnzbd.WINTRAY.sendnotification(title, msg)
-    except:
+    except Exception:
         logging.info(T("Failed to send Windows notification"))
         logging.debug("Traceback: ", exc_info=True)
         return T("Failed to send Windows notification")
