@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
 """
 tests.test_misc - Testing functions in encoding.py
 """
+import pytest
 
 import sabnzbd.encoding as enc
 
@@ -68,3 +69,44 @@ class TestEncoding:
         raw_input = "aaa" + chr(0xF0) + chr(0x9F) + "zzz"  # two bytes (instead of four) ... not valid UTF8
         corrected_output = enc.correct_cherrypy_encoding(raw_input)
         assert corrected_output == raw_input  # check nothing changed
+
+    def test_limit_encoded_length(self):
+        # Test with empty string
+        assert enc.limit_encoded_length("", 10) == "", "Empty string should return empty string"
+
+        # Test with string shorter than the limit
+        assert enc.limit_encoded_length("hello", 10) == "hello"
+
+        # Test with string equal to the limit
+        assert enc.limit_encoded_length("hello", 5) == "hello", "String equal to limit should return the same string"
+
+        # Test with string longer than the limit
+        assert enc.limit_encoded_length("hello world", 5) == "hello", "String longer than limit should be truncated"
+
+        # Test with UTF-8 characters
+        assert enc.limit_encoded_length("héllö wørld", 10) == "héllö w", "UTF-8 characters should be handled correctly"
+
+        # Test with emojis (multibyte characters)
+        assert enc.limit_encoded_length("😀😂🤣😃😄😅😆😉😊😋😎😍", 30) == "😀😂🤣😃😄😅😆"
+
+        # Test with invalid UTF-8 (single surrogate)
+        invalid_utf8 = b"\xed\xa0\x80".decode("latin-1")
+        limited_string = enc.limit_encoded_length(invalid_utf8, 3)
+        assert len(limited_string) == 1, "Invalid UTF-8 should be handled without raising an exception"
+
+        # Test with mixed valid and invalid UTF-8
+        mixed_string = "hello" + b"\xed\xa0\x80".decode("latin-1") + "world"
+        limited_string = enc.limit_encoded_length(mixed_string, 8)
+        assert "hello" in limited_string, "Valid part of mixed string should be present"
+        assert len(limited_string) <= 8, "Length of mixed string should be limited"
+
+        # Parametrized tests for various string and length combinations
+        test_cases = [
+            ("", 5, ""),
+            ("short", 10, "short"),
+            ("longstring", 4, "long"),
+            ("üöä", 4, "üö"),  # Test for umlauts
+            ("你好世界", 4, "你"),  # Test for CJK characters
+        ]
+        for input_string, max_len, expected in test_cases:
+            assert enc.limit_encoded_length(input_string, max_len) == expected
